# ImageAnalyst TF

ImageAnalyst TF is an extension to the [ImageAnalyst](https://github.com/BergLucas/ImageAnalyst) library, providing additional models and functions using [tensorflow](https://pypi.org/project/tensorflow/).

## Requirements

The application requires:

- [Python](https://www.python.org/) >=3.9, <3.12
- [pip](https://pip.pypa.io/en/stable/)

## Download

You can download the application on the [downloads page](https://github.com/BergLucas/ImageAnalystTF/releases).

## Installation

You can install the application by running the following command:

```bash
pip install image_analyst_tf-X.X.X-py3-none-any.whl
```

(Note: The X.X.X must be replaced by the version that you want to install.)

## License

All code is licensed for others under a MIT license (see [LICENSE](https://github.com/BergLucas/ImageAnalystTF/blob/main/LICENSE)).
